//+------------------------------------------------------------------+
//|                                                      Beltime.mq4 |
//|                               Copyright  2012, Gehtsoft USA LLC |
//|                                            http://fxcodebase.com |
//+------------------------------------------------------------------+
#property copyright "Copyright  2012, Gehtsoft USA LLC"
#property link      "http://fxcodebase.com"

#property indicator_separate_window
#property indicator_buffers 3

extern int    N               = 5;
extern int    MaxBars         = 100;
extern color  Bullish         = MediumSeaGreen;
extern color  Bearish         = Orange;
extern int    CandleWidth     = 3;
extern double upperLevel      = 10;
extern double lowerLevel      = -10;
extern bool   alertsOn        = true;
extern bool   alertsOnCurrent = true;
extern bool   alertsMessage   = true;
extern bool   alertsSound     = false;
extern bool   alertsNotify    = true;
extern bool   alertsEmail     = true;
extern string soundFile       = "alert2.wav"; 

double PrH[], PrL[], trend[];

int Window;

int init()
  {
   IndicatorBuffers(3);
   IndicatorShortName("Belkayate timing indicator");
   IndicatorDigits(Digits);
   SetIndexStyle(0,DRAW_NONE);
   SetIndexBuffer(0,PrH);
   SetIndexStyle(1,DRAW_NONE);
   SetIndexBuffer(1,PrL);
   SetIndexBuffer(2,trend);
   SetLevelValue(0,upperLevel);
   SetLevelValue(1,lowerLevel);

   return(0);
  }

int deinit()
  {
   Window=WindowFind("Belkayate timing indicator");
   if (Window!=-1)
   {
    ObjectsDeleteAll(Window, OBJ_TREND);
   }
   return(0);
  }

void DrawCandle(datetime T, double O, double H, double L, double C)
{
 string ObjName=""+T;
 double MaxBody=MathMax(O, C);
 double MinBody=MathMin(O, C);
 color CandleColor;
 if (C>=O) CandleColor=Bullish; else CandleColor=Bearish;
 Window=WindowFind("Belkayate timing indicator");
 if (Window==-1) return;
 if (ObjectFind(ObjName+"R")!=-1)
 {
  ObjectSet(ObjName+"R", OBJPROP_TIME1, T);
  ObjectSet(ObjName+"R", OBJPROP_TIME2, T);
  ObjectSet(ObjName+"R", OBJPROP_PRICE1, O);
  ObjectSet(ObjName+"R", OBJPROP_PRICE2, C);
 }
 else
 {
  ObjectCreate(ObjName+"R", OBJ_TREND, Window, T, O, T, C);
 } 
 ObjectSet(ObjName+"R", OBJPROP_COLOR, CandleColor);
 ObjectSet(ObjName+"R", OBJPROP_RAY, false);
 ObjectSet(ObjName+"R", OBJPROP_WIDTH, CandleWidth);
 
 if (ObjectFind(ObjName+"H")!=-1)
 {
  ObjectSet(ObjName+"H", OBJPROP_TIME1, T);
  ObjectSet(ObjName+"H", OBJPROP_TIME2, T);
  ObjectSet(ObjName+"H", OBJPROP_PRICE1, MaxBody);
  ObjectSet(ObjName+"H", OBJPROP_PRICE2, H);
 }
 else
 {
  ObjectCreate(ObjName+"H", OBJ_TREND, Window, T, MaxBody, T, H);
 } 
 ObjectSet(ObjName+"H", OBJPROP_COLOR, CandleColor);
 ObjectSet(ObjName+"H", OBJPROP_RAY, false);
 ObjectSet(ObjName+"H", OBJPROP_WIDTH, 1);

 if (ObjectFind(ObjName+"L")!=-1)
 {
  ObjectSet(ObjName+"L", OBJPROP_TIME1, T);
  ObjectSet(ObjName+"L", OBJPROP_TIME2, T);
  ObjectSet(ObjName+"L", OBJPROP_PRICE1, MinBody);
  ObjectSet(ObjName+"L", OBJPROP_PRICE2, L);
 }
 else
 {
  ObjectCreate(ObjName+"L", OBJ_TREND, Window, T, MinBody, T, L);
 } 
 ObjectSet(ObjName+"L", OBJPROP_COLOR, CandleColor);
 ObjectSet(ObjName+"L", OBJPROP_RAY, false);
 ObjectSet(ObjName+"L", OBJPROP_WIDTH, 1);
 return;
}  

int start()
{
 if(Bars<=3) return(0);
 int ExtCountedBars=IndicatorCounted();
 if (ExtCountedBars<0) return(-1);
 int pos;
 int limit=Bars-2;
 int bar;
 double O, H, L, C;
 double MaH, MaL;
 double avg1, avg2;
 if(ExtCountedBars>2) limit=Bars-ExtCountedBars-1;
 limit=MathMin(limit, MaxBars);
 pos=limit;
 while(pos>=0)
 {
  MaH=iMA(NULL, 0, N, 0, MODE_SMA, PRICE_HIGH, pos);
  MaL=iMA(NULL, 0, N, 0, MODE_SMA, PRICE_LOW, pos);
  avg1=(MaH+MaL)/2;
  avg2=(MaH-MaL)/5;
  O=(Open[pos]-avg1)/avg2;
  H=(High[pos]-avg1)/avg2;
  L=(Low[pos]-avg1)/avg2;
  C=(Close[pos]-avg1)/avg2;
  DrawCandle(Time[pos],O,H,L,C);
  PrH[pos]=H;
  PrL[pos]=L;
  trend[pos] = trend[pos+1];
  if (PrH[pos]>upperLevel) trend[pos] =-1;
  if (PrL[pos]<lowerLevel) trend[pos] = 1;
  
  pos--;
  } 
  
  //
  //
  //
  //
  //
      
  if (alertsOn)
  {
     if (alertsOnCurrent)
          int whichBar = 0;
     else     whichBar = 1; 
     if (trend[whichBar] != trend[whichBar+1])
     if (trend[whichBar] == 1)
           doAlert("Buy");
     else  doAlert("Sell");       
   }
return(0);
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," Beltime ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," Beltime " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Beltime "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}
 

